# Based on spec file from repoforge (dag)
# https://github.com/repoforge/rpms/tree/master/specs/havp

%if ! 0%{?make_build:1}
%define make_build %{__make} %{?_smp_mflags}
%endif

%global username havp

Summary: HTTP anti-virus proxy filter
Name: havp
Version: 0.93
Release: 2%{?dist}.zenetys
License: GPL
Group: System Environment/Daemons
URL: http://www.havp.org/

Source0: http://www.havp.org/download/havp-%{version}.tar.gz
Source1: havp.service
Source2: havp.tmpfiles
Patch0: https://raw.githubusercontent.com/repoforge/rpms/master/specs/havp/havp-init.patch
Patch1: https://salsa.debian.org/lts-team/packages/havp/-/raw/debian/bullseye/debian/patches/0001-Do-not-call-cl_strerror.patch

BuildRequires: bzip2-devel
BuildRequires: curl-devel
BuildRequires: findutils
BuildRequires: gmp-devel
BuildRequires: gcc-c++
BuildRequires: make
BuildRequires: openssl-devel
BuildRequires: perl

%if 0%{?rhel} >= 7
BuildRequires: clamav-devel
BuildRequires: systemd
%endif

Requires(pre): /usr/bin/getent
Requires(pre): /usr/sbin/groupadd
Requires(pre): /usr/sbin/useradd
Requires(postun): /usr/sbin/userdel

%if 0%{?rhel} >= 7
Requires(post):    systemd
Requires(preun):   systemd
Requires(postun):  systemd
%else
Requires(post):    /sbin/chkconfig
Requires(preun):   /sbin/chkconfig
Requires(preun):   /sbin/service
%endif

%if 0%{?rhel} >= 7
Requires: clamav-lib >= 1.0.8
%endif

%description
HAVP (HTTP AntiVirus proxy) is a proxy with an anti-virus filter.
It does not cache or filter content. At the moment the complete
traffic is scanned. The reason for this is the chance of malicious
code in nearly every filetype e.g. HTML (JavaScript) or Jpeg.

I aim to stop especially dialer or browser exploits. But writing
a http Anti Virus Proxy is a real dilemma! Huge downloads are
a problem for virus scanning proxies. A Client should not receive
data which is unchecked by the virus scanner, but big downloads
should not timeout.

%prep
%setup
%patch0 -p0 -b .init
%if 0%{?rhel} >= 8
%patch1 -p1 -b .libclamav-abi
%endif

%build
%configure \
	--enable-ssl-tunnel \
%if 0%{?rhel} <= 6
    --disable-clamav \
%endif
%if 0%{?rhel} >= 8
    --disable-locking \
%endif

%make_build

%install
install -Dp -m 0755 havp/havp %{buildroot}%{_sbindir}/havp

%if 0%{?rhel} >= 7
install -Dp -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/havp.service
install -Dp -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/havp.conf
%else
install -Dp -m 0755 etc/init.d/havp %{buildroot}%{_initrddir}/havp
%endif

install -d -m 0755 %{buildroot}%{_sysconfdir}/havp/
cp -a etc/havp/blacklist %{buildroot}%{_sysconfdir}/havp/
cp -a etc/havp/havp.config %{buildroot}%{_sysconfdir}/havp/
cp -a etc/havp/templates %{buildroot}%{_sysconfdir}/havp/
cp -a etc/havp/whitelist %{buildroot}%{_sysconfdir}/havp/
find %{buildroot}%{_sysconfdir}/havp/ -type d -exec chmod 0755 {} \;
find %{buildroot}%{_sysconfdir}/havp/ -type f -exec chmod 0644 {} \;

# do not enable any scanner by default
sed -i -re 's,^(\s*ENABLECLAMLIB)\s+.*,\1 false,' %{buildroot}%{_sysconfdir}/havp/havp.config

install -d -m 0755 %{buildroot}%{_localstatedir}/log/havp/
install -d -m 0755 %{buildroot}%{_localstatedir}/run/havp/
install -d -m 0755 %{buildroot}%{_localstatedir}/spool/havp/

%pre
/usr/bin/getent group %username >/dev/null ||
    /usr/sbin/groupadd -r %username &>/dev/null || :
/usr/bin/getent passwd %username >/dev/null ||
    /usr/sbin/useradd -r -s /sbin/nologin -d%{_localstatedir}/log/havp -M \
    -c 'HTTP anti-virus proxy filter' -g %username %username &>/dev/null || :

%post
%if 0%{?rhel} >= 7
%systemd_post havp.service
%else
/sbin/chkconfig --add havp
%endif

%preun
%if 0%{?rhel} >= 7
%systemd_preun havp.service
%else
if [ $1 -eq 0 ]; then
	/sbin/service havp stop &>/dev/null || :
	/sbin/chkconfig --del havp
fi
%endif

%postun
%if 0%{?rhel} >= 7
%systemd_postun_with_restart havp.service
%endif
if [ $1 -eq 0 ]; then
	/usr/sbin/userdel %username || :
	/usr/sbin/userdel %username || :
fi

%files
%defattr(-, root, root, 0755)
%doc ChangeLog COPYING INSTALL update-conf
%config(noreplace) %{_sysconfdir}/havp/

%if 0%{?rhel} >= 7
%{_unitdir}/havp.service
%{_tmpfilesdir}/havp.conf
%else
%{_initrddir}/havp
%endif

%{_sbindir}/havp

%defattr(-, %username, %username, 0755)
%{_localstatedir}/log/havp/
%{_localstatedir}/run/havp/
%{_localstatedir}/spool/havp/
